@@ -1,19 +1,18 @@
 /*
- * Copyright 2020 2021 Han Young <hanyoung@protonmail.com>
+ * SPDX-FileCopyrightText: 2020-2021 Han Young <hanyoung@protonmail.com>
  * SPDX-FileCopyrightText: 2020 Devin Lin <espidev@gmail.com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "locationquerymodel.h"
+#include "weatherlocationlistmodel.h"
 
 #include <KWeatherCore/LocationQueryReply>
 
 #include <QDebug>
 #include <QTimer>
 
-#include "weatherlocationmodel.h"
-
 LocationQueryModel::LocationQueryModel()
 {
     inputTimer = new QTimer(this);
